@@ -21,6 +21,8 @@ class ImgUpload(object):
 
     images_url = "https://imgchr.com/i/%s"
 
+    is_login = False
+
     @property
     def data_dict(self):
         return {
@@ -45,6 +47,7 @@ class ImgUpload(object):
         }
         self.sess.post("https://imgchr.com/login",
                        data=login_dict, headers=self.headers)
+        self.is_login = True
 
     def __load_username_password_from_local(self) -> Union[str, str]:
         this_file_path = Path(__file__).parent
@@ -60,9 +63,10 @@ class ImgUpload(object):
     def __init__(self) -> None:
         self.sess = requests.Session()
         # 获取原始的token，与账号关联
-        self.__login()
 
     def uploadImage(self, name, path) -> Tuple[str, str, str]:
+        if not self.is_login:
+            self.__login()
         with open(path, 'rb') as f:
             file_dict = {'source': (name, f)}
 
@@ -80,6 +84,8 @@ class ImgUpload(object):
             return return_res
 
     def uploadMulImages(self, names, paths) -> List[Tuple[str, str, str]]:
+        if not self.is_login:
+            self.__login()
         assert len(names) == len(paths), "name和path长度不相同"
         res_list = list()
         for name, path in tqdm(zip(names, paths), total=len(names), desc="uploading..."):
